@@ -28,13 +28,12 @@
 
 ;;; Code:
 
-(defvar agda2-version "2.6.2"
+(defvar agda2-version "2.6.4.3"
   "The version of the Agda mode.
 Note that the same version of the Agda executable must be used.")
 
 (require 'cl-lib)
 (require 'compile)
-(require 'pp)
 (require 'time-date)
 (require 'eri)
 (require 'annotation)
@@ -108,10 +107,6 @@ argument, and does not need to be listed here."
   :type 'string
   :group 'agda2)
 
-(defcustom agda2-toplevel-module "Agda.Interaction.GhciTop"
-  "The name of the Agda toplevel module."
-  :type 'string :group 'agda2)
-
 (defcustom agda2-information-window-max-height
   0.35
   "The maximum height of the information window.
@@ -265,8 +260,8 @@ constituents.")
   "Table of commands, used to build keymaps and menus.
 Each element has the form (CMD &optional KEYS WHERE DESC) where
 CMD is a command; KEYS is its key binding (if any); WHERE is a
-list which should contain 'local if the command should exist in
-the goal menu and 'global if the command should exist in the main
+list which should contain \\='local if the command should exist in
+the goal menu and \\='global if the command should exist in the main
 menu; and DESC is the description of the command used in the
 menus.")
 
@@ -534,7 +529,7 @@ process."
 Sends the list of strings ARGS to the Agda2 interpreter, waits
 for output and executes the responses, if any.
 
-If SAVE is 'save, then the buffer is saved first.
+If SAVE is \\='save, then the buffer is saved first.
 
 If HIGHLIGHT is non-nil, then the buffer's syntax highlighting
 may be updated. This is also the case if the Agda process is
@@ -606,10 +601,10 @@ May be more efficient than restarting Agda."
                       "Cmd_abort"))
 
 (defun agda2-abort-done ()
-  "Removes annotations, resets certain variables.
+  "Resets certain variables.
 Intended to be used by the backend if an abort command was
 successful."
-  (agda2-remove-annotations)
+  (agda2-info-action "*Aborted*" "Aborted." t)
   (setq agda2-highlight-in-progress nil
         agda2-last-responses        nil))
 
@@ -763,13 +758,13 @@ The user input is computed as follows:
   contains whitespace, then the input is taken from the
   minibuffer. In this case WANT is used as the prompt string.
 
-* Otherwise (including if WANT is 'goal) the goal contents are
+* Otherwise (including if WANT is \\='goal) the goal contents are
   used.
 
 If the user input is not taken from the goal, then an empty goal
 range is given.
 
-If SAVE is 'save, then the buffer is saved just before the
+If SAVE is \\='save, then the buffer is saved just before the
 command is sent to Agda (if it is sent)."
   (cl-multiple-value-bind (o g) (agda2-goal-at (point))
     (unless g (error "For this command, please place the cursor in a goal"))
@@ -896,8 +891,8 @@ of new goals."
  (agda2-goal-cmd "Cmd_autoOne" 'save 'goal))
 
 (defun agda2-autoAll ()
-  (interactive)
   "Solves all goals by simple proof search."
+  (interactive)
   (agda2-go nil nil 'busy t "Cmd_autoAll")
 )
 
@@ -1306,7 +1301,8 @@ top-level scope."
 
 (agda2-maybe-normalised
  agda2-elaborate-give
- "Elaborate check the given expression against the hole's type and fill in hole with the elaborated term"
+ "Elaborate check the given expression against the hole's type and fill in the
+ hole with the elaborated term"
  "Cmd_elaborate_give"
  "expression to elaborate and give")
 
@@ -1324,7 +1320,8 @@ top-level scope."
 
 (agda2-maybe-normalised
  agda2-goal-and-context-and-checked
- "Shows the context, the goal and check the given expression's against the hole's type"
+ "Shows the context, the goal and check the given expression's against
+ the hole's type"
  "Cmd_goal_type_context_check"
  "expression to type")
 
@@ -1651,7 +1648,12 @@ text properties."
     (error "no process")))
 
 (defun agda2-intersperse (sep xs)
-  (let(ys)(while xs (push (pop xs) ys)(push sep ys))(pop ys)(nreverse ys)))
+  (let (ys)
+    (while xs
+      (push (pop xs) ys)
+      (push sep ys))
+    (pop ys)
+    (nreverse ys)))
 
 (defun agda2-goal-Range (o)
   "The Haskell Range of goal overlay O."
@@ -1696,10 +1698,10 @@ points < 128) are converted to singleton strings."
 Removes any text properties, escapes newlines, double quotes,
 etc., adds surrounding double quotes, and converts non-ASCII
 characters to the \\xNNNN notation used in Haskell strings."
-  (let ((pp-escape-newlines t)
+  (let ((print-escape-newlines t)
         (s2 (copy-sequence s)))
     (set-text-properties 0 (length s2) nil s2)
-    (mapconcat 'agda2-char-quote (pp-to-string s2) "")))
+    (mapconcat 'agda2-char-quote (prin1-to-string s2) "")))
 
 (defun agda2-list-quote (strings)
   "Convert a list of STRINGS into a string representing it in Haskell syntax."
@@ -1951,7 +1953,7 @@ the argument is a positive number, otherwise turn it off."
 
 (defun agda2-get-agda-program-versions ()
   "Get \"version strings\" of executables starting with
-'agda-mode' in current path."
+\\='agda-mode\\=' in current path."
   (delete-dups
    (mapcar (lambda (path)
              ;; strip 'agda-mode' prefix
@@ -1976,7 +1978,10 @@ the argument is a positive number, otherwise turn it off."
 This command assumes that the agda and agda-mode executables for
 Agda version VERSION are called agda-VERSION and
 agda-mode-VERSION, and that they are located on the PATH. (If
-VERSION is empty, then agda and agda-mode are used instead.)"
+VERSION is empty, then agda and agda-mode are used instead.)
+
+An attempt is made to preserve the default value of
+`agda2-mode-hook'."
   (interactive
    (list (completing-read "Version: " (agda2-get-agda-program-versions))))
 
@@ -1988,6 +1993,8 @@ VERSION is empty, then agda and agda-mode are used instead.)"
                       (list buf))))
                 (buffer-list)))
 
+       (default-hook (default-value 'agda2-mode-hook))
+
        (version-suffix (if (or (equal version "")
                                (equal version nil))
                            ""
@@ -2042,6 +2049,10 @@ VERSION is empty, then agda and agda-mode are used instead.)"
     (require 'agda2-mode)
     (setq agda2-program-name (concat "agda" version-suffix))
 
+    ;; Restore the Agda mode's default hook (if any).
+    (when default-hook
+      (set-default 'agda2-mode-hook default-hook))
+
     ;; Restart the Agda mode in all former Agda mode buffers.
     (mapc (lambda (buf)
             (with-current-buffer buf
